-- PricePer version 1.1
-- Based on the idea of PricePer, but using Ace2...
-- If no buyout price, then show the price for bidding (which might need the bid increase price too)

local L = AceLibrary("AceLocale-2.2"):new("PricePer")

PricePer = AceLibrary("AceAddon-2.0"):new("AceHook-2.1", "AceConsole-2.0", "AceDB-2.0")
local A = AceLibrary("Abacus-2.0")

PricePer:RegisterDB("PricePerDB", "PricePerDBPC")
PricePer:RegisterDefaults("profile", {
    warn_price = 5,
	highlight = 10
} )

function PricePer:OnInitialize()
	local options = { 
		type='group',
		args = {
			warn = {
				name = L["Warn"], type = 'range', step = 1,
				desc = L["Sets the warning value per item."],
				usage = L["<price in gold>"],
				get = function() return self.db.profile.warn_price end,
				set = function(num) self.db.profile.warn_price = num end,
				min  = 0, max  = 100,
			},
			highlight = {
				name = L["Highlight"], type = 'range', step = 1,
				desc = L["Highlight items that have a Bid this far below the Buyout."],
				usage = L["<percentage of buyout>"],
				get = function() return self.db.profile.highlight end,
				set = function(num) self.db.profile.highlight = num end,
				min  = 0, max  = 100,
			},
		},
	}

	PricePer:RegisterChatCommand(L["Slash-Commands"], options)
end

function PricePer:OnEnable()
	self:SecureHook("AuctionFrameBrowse_Update")
end

function PricePer:AuctionFrameBrowse_Update()
	local offset = FauxScrollFrame_GetOffset(BrowseScrollFrame);
	
	for i=1, NUM_BROWSE_TO_DISPLAY do
		local name, _, count, _, _, _, min, inc, buy, bid =  GetAuctionItemInfo("list", offset + i);
		if name then
			local _, _, id = strfind(GetAuctionItemLink("list", offset + i) or "", "item:(%d+):")
			local _, _, _, _, _, _, _, stack = GetItemInfo(id);
			if stack>1 then
				bid = (bid>0 and (bid+inc) or min)
				local item, color, highlight = getglobal("BrowseButton"..i.."Name"), "3333ff", ""
				if self.db.profile.warn_price>0 then
					color = (floor((buy>0 and buy or bid)/count) > (self.db.profile.warn_price * 10000)) and "ff0000" or "00ff00"
				end
				local text = A:FormatMoneyFull(floor(bid/count),true)
				if buy>0 then
				 	text = text.." |cff"..color.."->|r "..A:FormatMoneyFull(floor(buy/count),true)
					if self.db.profile.highlight>0 and (bid * 100) <= (buy * self.db.profile.highlight) then
						highlight = "|cff00ffff*"
					end
				end
				item:SetText(item:GetText().."\n"..highlight.."|cff"..color.."(|r"..text.."|cff"..color..")|r")
			end
		end
	end
end
